@@ -17,7 +17,7 @@ class DingDingPlugin(NotificationPlugin):
     """
     author = 'dreamerldq'
     author_url = 'https://github.com/dreamerldq/sentry-dingding-format'
-    version = '1.0.16'
+    version = '1.0.17'
     description = 'Send project error counts to DingDing .'
     resource_links = [
         ('Source', 'https://github.com/dreamerldq/sentry-dingding-format'),
@@ -41,9 +41,12 @@ class DingDingPlugin(NotificationPlugin):
         self.post_process(group, event, *args, **kwargs)
 
     def getGroupCount(self, groupId):
-        url = 'http://localhost:9000/api/0/issues/{groupId}/'.format(groupId =groupId )
-        r = requests.get(url).json()
-        return r["count"]
+        url = f"/api/0/issues/{groupId}/"
+        response = self.client.get(url, format="json")
+
+        assert response.status_code == 200
+        assert response.data["id"] == str(groupId)
+        return response.data["count"]
 
     def post_process(self, group, event, *args, **kwargs):
         """
@@ -57,6 +60,8 @@ class DingDingPlugin(NotificationPlugin):
             return
 
         count = self.getGroupCount(group.id)
+        if(count>5):
+            return
 
         access_token = self.get_option('access_token', group.project)
         send_url = DingTalk_API.format(token=access_token)
